@@ -71,10 +71,12 @@
 #include <Qt3DRender/qstenciloperationarguments.h>
 #include <Qt3DRender/qfrustumculling.h>
 #include <Qt3DRender/qstenciltestarguments.h>
+#include <Qt3DRender/qnopicking.h>
 #include <Qt3DRender/qrenderpassfilter.h>
 #include <Qt3DRender/qcomputecommand.h>
 #include <Qt3DRender/qpickevent.h>
 #include <Qt3DRender/qrendersettings.h>
+#include <Qt3DRender/qshaderimage.h>
 #include <Qt3DRender/qpicktriangleevent.h>
 #include <Qt3DRender/qmultisampleantialiasing.h>
 #include <Qt3DRender/qtechniquefilter.h>
@@ -259,94 +261,98 @@ enum : int {
     SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX              = 84,
     SBK_QT3DRENDER_QNODEPTHMASK_IDX                          = 85,
     SBK_QT3DRENDER_QNODRAW_IDX                               = 86,
-    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 87,
-    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 88,
-    SBK_QT3DRENDER_QPARAMETER_IDX                            = 89,
-    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 90,
-    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 91,
-    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 92,
-    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 93,
-    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 94,
-    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 95,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 96,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 98,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 99,
-    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 97,
-    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 100,
-    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 101,
-    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 102,
-    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 103,
-    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 104,
-    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 105,
-    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 106,
-    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 107,
-    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 108,
-    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 109,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 110,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 111,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 112,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 113,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 114,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 115,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 116,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 117,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 118,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 119,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 120,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 121,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 122,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 123,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 125,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 124,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 126,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 127,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 128,
-    SBK_QT3DRENDER_QSETFENCE_IDX                             = 129,
-    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 130,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 131,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 132,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 133,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 134,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 135,
-    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 136,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 137,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 138,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 139,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 140,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 141,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 142,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 143,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 144,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 145,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 146,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 147,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 148,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 149,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 150,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 151,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 152,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 153,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 154,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 155,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 156,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 157,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 158,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 159,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 160,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 161,
-    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 162,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 163,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 164,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 165,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 166,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 167,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 168,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 169,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 170,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 171,
-    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 172,
-    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 173,
-    SBK_Qt3DRender_IDX_COUNT                                 = 174
+    SBK_QT3DRENDER_QNOPICKING_IDX                            = 87,
+    SBK_QT3DRENDER_QOBJECTPICKER_IDX                         = 88,
+    SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX                  = 89,
+    SBK_QT3DRENDER_QPARAMETER_IDX                            = 90,
+    SBK_QT3DRENDER_QPICKEVENT_IDX                            = 91,
+    SBK_QT3DRENDER_QPICKEVENT_BUTTONS_IDX                    = 92,
+    SBK_QT3DRENDER_QPICKEVENT_MODIFIERS_IDX                  = 93,
+    SBK_QT3DRENDER_QPICKLINEEVENT_IDX                        = 94,
+    SBK_QT3DRENDER_QPICKPOINTEVENT_IDX                       = 95,
+    SBK_QT3DRENDER_QPICKTRIANGLEEVENT_IDX                    = 96,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_IDX                      = 97,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKMETHOD_IDX           = 99,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_PICKRESULTMODE_IDX       = 100,
+    SBK_QT3DRENDER_QPICKINGSETTINGS_FACEORIENTATIONPICKINGMODE_IDX = 98,
+    SBK_QT3DRENDER_QPOINTLIGHT_IDX                           = 101,
+    SBK_QT3DRENDER_QPOINTSIZE_IDX                            = 102,
+    SBK_QT3DRENDER_QPOINTSIZE_SIZEMODE_IDX                   = 103,
+    SBK_QT3DRENDER_QPOLYGONOFFSET_IDX                        = 104,
+    SBK_QT3DRENDER_QPROXIMITYFILTER_IDX                      = 105,
+    SBK_QT3DRENDER_QRAYCASTER_IDX                            = 106,
+    SBK_QT3DRENDER_QRAYCASTERHIT_IDX                         = 107,
+    SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 108,
+    SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 109,
+    SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 110,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 111,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 112,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 113,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 114,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 115,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 116,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 117,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 118,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 119,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 120,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 121,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 122,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 123,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 124,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 126,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 125,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 127,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 128,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 129,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 130,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 131,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 132,
+    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 133,
+    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 134,
+    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 135,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 136,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 137,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 138,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 139,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 140,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 141,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 142,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 143,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 144,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 145,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 146,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 147,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 148,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 149,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 150,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 151,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 152,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 153,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 154,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 155,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 156,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 157,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 158,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 159,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 160,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 161,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 162,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 163,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 164,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 165,
+    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 166,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 167,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 168,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 169,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 170,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 171,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 172,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 173,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 174,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 175,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 176,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 177,
+    SBK_Qt3DRender_IDX_COUNT                                 = 178
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_Qt3DRenderTypes;
@@ -389,6 +395,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::PropertyReaderInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_PROPERTYREADERINTERFACE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QAbstractFunctor >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTFUNCTOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QAbstractLight::Type >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QABSTRACTLIGHT_TYPE_IDX]; }
@@ -475,6 +483,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QMesh >() { return reinte
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QMultiSampleAntiAliasing >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QMULTISAMPLEANTIALIASING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QNoDepthMask >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QNODEPTHMASK_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QNoDraw >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QNODRAW_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QNoPicking >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QNOPICKING_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QObjectPicker >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QOBJECTPICKER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QPaintedTextureImage >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QPAINTEDTEXTUREIMAGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QParameter >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QPARAMETER_IDX]); }
@@ -520,6 +529,9 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSeamlessCubemap >() { re
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSetFence::HandleType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QSetFence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSETFENCE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERDATA_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderImage::Access >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderImage::ImageFormat >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderImage >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERIMAGE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram::ShaderType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram::Status >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QShaderProgram >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QSHADERPROGRAM_IDX]); }
@@ -562,6 +574,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QTextureWrapMode >() { re
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QViewport >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QVIEWPORT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence::HandleType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QWaitFence >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QWAITFENCE_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
