@@ -220,6 +220,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QGeoCodeReply::Error >() { return SbkPySide2_QtLocationTypes[SBK_QGEOCODEREPLY_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QGeoCodeReply >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtLocationTypes[SBK_QGEOCODEREPLY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QGeoCodingManager >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtLocationTypes[SBK_QGEOCODINGMANAGER_IDX]); }
@@ -292,6 +294,7 @@ template<> inline PyTypeObject *SbkType< ::QPlaceSearchResult >() { return reint
 template<> inline PyTypeObject *SbkType< ::QPlaceSearchSuggestionReply >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtLocationTypes[SBK_QPLACESEARCHSUGGESTIONREPLY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPlaceSupplier >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtLocationTypes[SBK_QPLACESUPPLIER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPlaceUser >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtLocationTypes[SBK_QPLACEUSER_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
