@@ -85,13 +85,13 @@ enum : int {
     SBK_QtMultimediaWidgets_IDX_COUNT                        = 4
 };
 // This variable stores all Python types exported by this module.
-extern PyTypeObject** SbkPySide2_QtMultimediaWidgetsTypes;
+extern PyTypeObject **SbkPySide2_QtMultimediaWidgetsTypes;
 
 // This variable stores the Python module object exported by this module.
-extern PyObject* SbkPySide2_QtMultimediaWidgetsModuleObject;
+extern PyObject *SbkPySide2_QtMultimediaWidgetsModuleObject;
 
 // This variable stores all type converters exported by this module.
-extern SbkConverter** SbkPySide2_QtMultimediaWidgetsTypeConverters;
+extern SbkConverter **SbkPySide2_QtMultimediaWidgetsTypeConverters;
 
 // Converter indices
 enum : int {
@@ -111,10 +111,13 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QCameraViewfinder >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QCAMERAVIEWFINDER_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QGraphicsVideoItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QGRAPHICSVIDEOITEM_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QVideoWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGET_IDX]); }
-template<> inline PyTypeObject* SbkType< ::QVideoWidgetControl >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGETCONTROL_IDX]); }
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
+template<> inline PyTypeObject *SbkType< ::QCameraViewfinder >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QCAMERAVIEWFINDER_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QGraphicsVideoItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QGRAPHICSVIDEOITEM_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QVideoWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGET_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QVideoWidgetControl >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtMultimediaWidgetsTypes[SBK_QVIDEOWIDGETCONTROL_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
